@@ -2,15 +2,6 @@ from .base import ENDPOINT, any_required_kwargs, process_response
 
 
 class MoviesMixin:
-    @process_response
-    def get_movie_providers(self, movie_id, **kwargs):
-        """
-        GET /movie/{movie_id}/watch/providers
-        """
-
-        url = f"{ENDPOINT}/3/movie/{movie_id}/watch/providers"
-        return self.make_request("GET", url, kwargs)
-
     @process_response
     def get_movie_details(self, movie_id, **kwargs):
         """
@@ -147,6 +138,15 @@ class MoviesMixin:
         url = f"{ENDPOINT}/3/movie/{movie_id}/lists"
         return self.make_request("GET", url, kwargs)
 
+    @process_response
+    def get_movie_watch_providers(self, movie_id, **kwargs):
+        """
+        GET /movie/{movie_id}/watch/providers
+        """
+
+        url = f"{ENDPOINT}/3/movie/{movie_id}/watch/providers"
+        return self.make_request("GET", url, kwargs)
+
     @any_required_kwargs(["session_id"], ["guest_session_id"])
     @process_response
     def post_movie_rating(self, movie_id, rating, **kwargs):
